@@ -8,7 +8,6 @@ from pydantic import BaseModel, validate_arguments
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from ..types import AccountType, Currency
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/balances"
 
@@ -17,10 +16,10 @@ class BalanceRecord(BaseModel):
     description: Optional[str]
     balance: int
     ts: int
-    currency: Optional[Currency]
+    currency: Optional[str]
     labels: Set[str]
     account_id: str
-    account_type: Optional[AccountType]
+    account_type: Optional[str]
 
 
 class BalancesMeta(BaseModel):
@@ -36,7 +35,7 @@ class BalancesMeta(BaseModel):
 
 class BalancesAccount(BaseModel):
     account_id: str
-    account_type: Optional[AccountType]
+    account_type: Optional[str]
     records: List[BalanceRecord]
 
 
@@ -59,7 +58,7 @@ class BaseBalancesResource(ABC):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
         page: int = 1,
     ) -> BalancesResponse:
         async with self._client.session() as session:
@@ -86,7 +85,7 @@ class BaseBalancesResource(ABC):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -132,7 +131,7 @@ class AsyncBalancesResource(BaseBalancesResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
         return await self._get(
             user_uuid=user_uuid,
@@ -153,7 +152,7 @@ class SyncBalancesResource(BaseBalancesResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
-        account_types: Optional[Sequence[AccountType]] = None,
+        account_types: Optional[Sequence[str]] = None,
     ) -> List[BalanceRecord]:
         return self._client.run(
             self._get(
